pub fn validate_program_path(path: &Path) -> Result<()>Expand description
Validate that a program path exists and is a directory
Returns an error if the path does not exist or is not a directory. This is used to provide consistent error messages across all builders.